extensions [ csv gis ]
breed [ ants ant ]
breed [ cadavers cadaver ]

;;;; VARIABLES ;;;;;
ants-own [
  turn_avg ; mean of the turning distribution
  turn_var ; = 'turning-index' in inputs: standard deviation of turning angle. higher value = more turning
  step_size ; = 'step-length' in inputs: amount moved by ant in a tick.
  step_var ; standard deviation of step_size
  plant-timer
  plant-time
  on-plant ; boolean, whether ant is climbing plant
  current-patch
]

patches-own [
  zombie-density ; a measure of the intensity of cadavers found in that area, scaled from 0-1
]

globals [
  trails ; location of where the trails are
  zombie-density-raster ; raster which inputs the zombie-density values
  zombie-patches ; location of cadaver targets
  trail-patches ; location of trails
  zombie-heights ; input data on actual heights zombie ant cadavers found at
  cm_per_patch ; conversion factor from field to model size
  num-ants ; number of ants in run
  density-threshold ; lowest zombie-density a cadaver is found at
]

;;;;;;;;;;;;;;;;;;;; SETUP ;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup
  clear-all

  set-parameters
  build-world
  ask turtles [ die ]
  setup-ants

  reset-ticks
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to set-parameters
  ;set nest-patches patches with [abs(pxcor) < 2 and abs(pycor) < 2]
  set cm_per_patch 500 / (max-pxcor)
  set zombie-heights []

  ; field data is 500 x 500 so convert to model size:
  gis:set-transformation (list -500 500 -500 500)(list min-pxcor max-pxcor min-pycor max-pycor)
  ; load trail data:
  set trails gis:load-dataset (word "input_data/" nest ".shp")
  file-close

  ask patches [
    set zombie-density 0 ] ;initialize
end

to build-world
  draw-trails

  assign-density

  setup-targets (word "input_data/" nest ".csv")
  color-patches
end

to draw-trails
  gis:set-drawing-color brown
  gis:draw trails 2
  set trail-patches patches with [gis:intersects? trails self]
end

to assign-density
  set zombie-density-raster gis:load-dataset(word "input_data/" nest ".asc")
  gis:apply-raster zombie-density-raster zombie-density

  ask patches [
    if (zombie-density > 1)  [ ; a few patches outside boundary in input file, netlogo assigns arbitray number above 1
      set zombie-density 0 ; set patches without value as 0
    ]
  ]
end

to setup-targets [file]
  file-open file
  let first-line csv:from-row file-read-line
  while [ not file-at-end? ] [
    let row csv:from-row file-read-line
    ask patch (round (item 1 row) / cm_per_patch) (round (item 2 row / cm_per_patch))
    [set pcolor blue]
   set zombie-heights lput item 3 row zombie-heights
  ]
  file-close

  set zombie-patches patches with [pcolor = blue]
  ;set density-threshold round (min [zombie-density] of patches with [pcolor = blue] * 100)
  set density-threshold climbing-threshold * 100
end

to color-patches
   ask patches [
    ;set pcolor scale-color red zombie-density 1 0
    ifelse zombie-density > 0.75 [
      ;set pcolor scale-color red zombie-density 1.25 0
      set pcolor red
    ] [
      ifelse zombie-density > 0.4 [
       ; set pcolor scale-color orange zombie-density 1.5 0
        set pcolor orange
      ] [
          ;ifelse zombie-density > 0.25 [
            set pcolor scale-color yellow zombie-density 1 0] ;[
         ;     ;if zombie-density >= density-threshold / 100 [
              ;  set pcolor white ; ]
         ; ]
        ; ]
      ; ]
     ]
  ]

  ask zombie-patches [set pcolor blue]
end

to setup-ants
 set-default-shape ants "bug"
 set num-ants count zombie-patches

  create-ants num-ants [
    set size 10 / cm_per_patch ; actual ant size ~ 1cm, but made larger for visualization purposes
    set color black

    move-to one-of trail-patches
    set heading random 360; start heading in random direction

    ;;; variables
    set turn_avg 0
    set turn_var turning-index
    set step_size step-length / cm_per_patch
    set step_var 0.4 / cm_per_patch ;average st dev of step lengths from field data
    set on-plant false
    set plant-timer 0
    set current-patch patch-here
  ]

end


;;;;;;;;;;;;;;;;;;;; GO ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to go
  if not any? ants [ stop ]; if all ants have died or time limit reached

  if ticks = time-limit [
    ask ants [set breed cadavers] ; ants become cadavers at current location if time limit reached
    stop
  ]

  ask ants [
    ifelse on-plant [
      walk-on-plant
    ] [
      move
      ifelse climb-delay = 0 [
        update-patch
      ] [
        if ticks > climb-delay and remainder ticks climb-delay = 0 [ update-patch ]
      ]
    ]
  ]

  check-bounds   ; check if out of bounds
  tick
end

;;;;;;;;;;;;;;;;;;;;;; FUNCTIONS ;;;;;;;;;;;;;;;;;;;;;;;;
to move
  ;pen-down ; if want to see path tracing
  let turning-angle 0
  set turning-angle random-normal 0 turn_var
  rt turning-angle

  let dist random-normal step_size step_var
  if dist < 0 [ set dist 0 ] ; avoid moving backwards, but can stay in same spot
  fd dist
end

to update-patch
  if current-patch != patch-here [
    set current-patch patch-here
    evaluate-density
  ]
end

to evaluate-density
  ask ants [
    let chance random 100 + density-threshold

    if chance < ([zombie-density] of patch-here * 100)  [
      set on-plant true
      set color green
      set plant-time calculate-plant-time
      set plant-timer plant-time
    ]
  ]
end

to-report calculate-plant-time
  let height one-of zombie-heights
  report height * 2 ; times 2 to account for up and down
end

to walk-on-plant
  set plant-timer plant-timer - 1

  if plant-timer = 0 [
    set color black
    set on-plant false ]

  if plant-timer = plant-time / 2 [bite] ; evaluate biting halfway through climbing
end


to bite
    if random 100 < ([zombie-density] of patch-here * 100) [
      set breed cadavers
      set color violet
      set size 2
    ]
end

;; ant procedure. if out of bounds, ant dies
;; dies before max to avoid error of ant trying to walk outside of bounds
to check-bounds
  ifelse bounded?
  [
     ask ants [
      if xcor >= (max-pxcor - 0.1) [ rt 90 ]
      if xcor <= (min-pxcor + 0.1) [ rt 90 ]
      if ycor >= (max-pycor - 0.1) [ rt 90 ]
      if ycor <= (min-pycor + 0.1) [ rt 90 ]
    ]
  ] [
      ask ants [
      if xcor >= (max-pxcor - 0.1) [ die ]
      if xcor <= (min-pxcor + 0.1) [ die ]
      if ycor >= (max-pycor - 0.1) [ die ]
      if ycor <= (min-pycor + 0.1) [ die ]
    ]
  ]
end

to-report percent-error
  let diff 0
  let real-mean-density mean ([zombie-density] of patches with [pcolor = blue])

  ifelse not any? cadavers [
    set diff real-mean-density
  ] [
    set diff real-mean-density - ((sum ([zombie-density] of cadavers) + sum([zombie-density] of ants)) / num-ants)
  ]

  report  (diff / real-mean-density ) * 100
end
@#$#@#$#@
GRAPHICS-WINDOW
269
21
782
535
-1
-1
5.0
1
10
1
1
1
0
0
0
1
-50
50
-50
50
1
1
1
ticks
30.0

BUTTON
104
36
168
69
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
30
36
97
69
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
16
147
188
180
step-length
step-length
0.02
3
0.14
0.02
1
cells
HORIZONTAL

SLIDER
5
194
199
227
turning-index
turning-index
0
103.9
15.0
1
1
degrees
HORIZONTAL

CHOOSER
28
88
166
133
nest
nest
"nest1" "nest2" "nest3" "nest4"
1

SLIDER
15
344
187
377
time-limit
time-limit
0
109000
54000.0
1
1
NIL
HORIZONTAL

SLIDER
16
244
188
277
climb-delay
climb-delay
0
10000
150.0
10
1
NIL
HORIZONTAL

SWITCH
43
402
161
435
bounded?
bounded?
0
1
-1000

SLIDER
18
294
191
327
climbing-threshold
climbing-threshold
0
1
0.6
.1
1
NIL
HORIZONTAL

MONITOR
51
449
151
494
NIL
percent-error
17
1
11

@#$#@#$#@
## WHAT IS IT?

Zombie ants are ants manipulated by a fungal parasite (Ophiocordyceps sp.) to leave the nest and die biting the underside of a leaf. From there, the fungus grows from the ant and distributes spores to new ants. 

This model replicates the zombie ant system of the carpenter ant Camponotus rufipes infected with Ophiocordyceps camponoti-rufipedis. A field study (Loreto, 2014) mapped out the location of the ant trails (brown lines) and zombie ant cadavers (blue squares). We include four nest set-ups where this data was measured. The nest is located at the center of the environement (0,0) and all trails emerge from the nest. 

Infected ants likely follow these trails out of the nest and then fall off the trails to end up biting on vegetation in the environment. The model attempts to recreate how infected ants are walking  to the biting locations. By altering the movement parameters of the ants, we can test what impacts whether ants frequently end up on the biting locations.

The color of each patch in the environment reflects the scaled 'zombie-density' in that area as determined by the blue cadaver targets. White squares indicate low zombie-density, followed by yellow, then orange, and finally red squares indicating the highest zombie-density. Zombie-density is a scaled value of 0-1 from the spatial intensity of the cadaver points.

## HOW TO USE IT

The SETUP button initializes the model. The model begins with a number of ants equal to the number of cadaver targets (blue squares) and the ants begin at random points along the trail. 

There are four different NEST setups. Select from the drop down menu to choose a different setup. Each nest replicates the field data from Loreto (2014). 

The GO button starts the ants moving. 

Ant movement is controlled by the values of TURNING-INDEX and STEP-LENGTH. The distance an ant travels in a tick is determined from the STEP-LENGTH. The amount an ant turns in a step is determined randomly from a gaussian distribution, with 0 as the mean and TURNING-INDEX as the standard deviation.

At every interval of steps determined by CLIMB-DELAY, the ant agents assess the zombie-density at their current patch. The color of the patch indicates how high or low the density is there. If the zombie-density is above CLIMBING-THRESHOLD, then the ant may climb a plant with a probability determined by the zombie-density at that patch. When an ant is climbing a plant, it turns green and remains at that patch for a time determined by the height of the plant (from the input data of the actual heights the cadavers were found at) and its step length. While climbing a plant, an ant may bite at that location and turn into a cadaver. Ants turn into purple triangles when they have become a cadaver. 
If bounded? is on, the ants cannot exit the environment. If it is off, ants will exit and not return. 

The ants move through the environment until they bite and turn into a cadaver or they exit the arena. The model stops when all ants have hit a cadaver location or
exited the arena.

The success of a run is measured by the percent error, which calculates the difference between the mean cadaver-density at the blue patches (actual cadaver locations) and mean cadaver-density of the simulated ants in the run. 

## CREDITS AND REFERENCES

Loreto, R. G., Elliot, S. L., Freitas, M. L., Pereira, T. M., & Hughes, D. P. (2014). Long-term disease dynamics for a specialized parasite of ant societies: a field study. PloS one, 9(8), e103516.


## HOW TO CITE

If you mention this model or the NetLogo software in a publication, we ask that you include the citations below.

Please cite the NetLogo software as:

* Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.3
@#$#@#$#@
setup
repeat 250 [ go ]
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="calibration" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="166000"/>
    <exitCondition>not any? ants</exitCondition>
    <metric>fitness</metric>
    <metric>find-fitness</metric>
    <metric>count ants</metric>
    <metric>[xcor] of ants</metric>
    <metric>[ycor] of ants</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest4&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="step-length" first="0.3" step="0.2" last="1.7"/>
    <steppedValueSet variable="turn-mean" first="-25" step="5" last="15"/>
    <enumeratedValueSet variable="time-on-trail">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trail-movement?">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="turning-index" first="0" step="5" last="20"/>
    <enumeratedValueSet variable="backwards?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="time-on-trail" repetitions="30" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="108000"/>
    <metric>sum [fitness] of turtles</metric>
    <enumeratedValueSet variable="step-length">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turn-mean">
      <value value="0.07"/>
    </enumeratedValueSet>
    <steppedValueSet variable="time-on-trail" first="500" step="500" last="10000"/>
    <enumeratedValueSet variable="trail-movement?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turning-index">
      <value value="18.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest1&quot;"/>
      <value value="&quot;nest4&quot;"/>
      <value value="&quot;nest5&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="testing" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="166000"/>
    <exitCondition>not any? ants</exitCondition>
    <metric>fitness</metric>
    <metric>find-fitness</metric>
    <metric>count ants</metric>
    <metric>[xcor] of ants</metric>
    <metric>[ycor] of ants</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest4&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="step-length" first="0.2" step="0.2" last="0.6"/>
    <steppedValueSet variable="turn-mean" first="-45" step="15" last="45"/>
    <enumeratedValueSet variable="time-on-trail">
      <value value="600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trail-movement?">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="turning-index" first="5" step="15" last="100"/>
    <enumeratedValueSet variable="backwards?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-time">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="turning-rate" repetitions="5" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="108000"/>
    <metric>find-fitness</metric>
    <metric>[turn_rate] of cadavers</metric>
    <enumeratedValueSet variable="step-length">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest4&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turn-mean">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="switch-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trail-movement?">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="turning-index" first="0" step="10" last="100"/>
    <enumeratedValueSet variable="backwards?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="measure-distance" repetitions="5" sequentialRunOrder="false" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="108000"/>
    <exitCondition>count ants = 0</exitCondition>
    <metric>fitness / num-ants</metric>
    <metric>f1</metric>
    <metric>f2</metric>
    <metric>f3</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest4&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step-length">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turn-mean">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="turning-index" first="0" step="10" last="100"/>
    <enumeratedValueSet variable="trail-turn">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="trail-movement?">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="climbing_test" repetitions="5" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>percent-error2</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest1&quot;"/>
      <value value="&quot;nest2&quot;"/>
      <value value="&quot;nest3&quot;"/>
      <value value="&quot;nest4&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step-length">
      <value value="0.5"/>
      <value value="1"/>
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turning-index">
      <value value="15"/>
      <value value="45"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climb-delay">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bounded?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit">
      <value value="54000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climbing-threshold">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="heat-map" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>[xcor] of cadavers</metric>
    <metric>[ycor] of cadavers</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bounded?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step-length">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turning-index">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit">
      <value value="54000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climb-delay">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climbing-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="plant-limit" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>percent-error2</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bounded?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step-length">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="turning-index">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-limit">
      <value value="54000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="plant-limit" first="2" step="2" last="50"/>
  </experiment>
  <experiment name="experiment1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>percent-error</metric>
    <metric>percent-error2</metric>
    <enumeratedValueSet variable="nest">
      <value value="&quot;nest1&quot;"/>
      <value value="&quot;nest2&quot;"/>
      <value value="&quot;nest3&quot;"/>
      <value value="&quot;nest4&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="step-length">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bounded?">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="turning-index" first="5" step="15" last="90"/>
    <enumeratedValueSet variable="time-limit">
      <value value="54000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="climb-delay">
      <value value="300"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
